Add an assay to an object
add_assay.RdAdds an assay object to a container object.
Arguments
- object
The object to which the assay will be added.
- assay
The assay object to add.
- name
Optional character string specifying the assay name. If `NULL`, the assay object's existing `name` slot is used.
- overwrite
Logical value indicating whether to overwrite an existing assay with the same name.
- ...
Additional arguments passed to methods.