Create a donut plot from model metadata
plot_donut-OncoExperiment-method.RdGenerates a donut plot that shows the distribution of categorical metadata fields from a selected assay in an `OncoExperiment`.
Usage
# S4 method for class 'OncoExperiment'
plot_donut(
object,
variable,
assay,
variable_expr = substitute(variable),
show_na = FALSE,
...
)